==> jc-1.4.0.tar.gz: javax/swing/Spring__24SimpleSpring.h <==
// final class javax.swing.Spring$SimpleSpring

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 52c68a5c6f02978c javax_swing_Spring
// @dep_class 53749d8f1d14809a javax_swing_Spring__24SimpleSpring

// header file dependencies
// @dep_header javax_swing_Spring

#include "javax/swing/Spring.h"

#ifndef _JC_javax_swing_Spring__24SimpleSpring_H_
#define _JC_javax_swing_Spring__24SimpleSpring_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_Spring__24SimpleSpring$sub_refs	_jc_javax_swing_Spring__24SimpleSpring$sub_refs;
typedef struct _jc_javax_swing_Spring__24SimpleSpring$sub_nonrefs	_jc_javax_swing_Spring__24SimpleSpring$sub_nonrefs;
typedef struct _jc_javax_swing_Spring__24SimpleSpring$refs	_jc_javax_swing_Spring__24SimpleSpring$refs;
typedef struct _jc_javax_swing_Spring__24SimpleSpring$nonrefs	_jc_javax_swing_Spring__24SimpleSpring$nonrefs;
typedef struct _jc_javax_swing_Spring__24SimpleSpring$object	_jc_javax_swing_Spring__24SimpleSpring$object;

typedef const struct _jc_javax_swing_Spring__24SimpleSpring$vmethods	_jc_javax_swing_Spring__24SimpleSpring$vmethods;
typedef const struct _jc_javax_swing_Spring__24SimpleSpring$vtable	_jc_javax_swing_Spring__24SimpleSpring$vtable;
typedef const struct _jc_javax_swing_Spring__24SimpleSpring$vtype	_jc_javax_swing_Spring__24SimpleSpring$vtype;

// Constructors
extern void _jc_javax_swing_Spring__24SimpleSpring$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *, jint, jint, jint);

// Virtual methods
extern jint _jc_javax_swing_Spring__24SimpleSpring$method$getMaximumValue$dd51e3d6fecde040(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *);
extern jint _jc_javax_swing_Spring__24SimpleSpring$method$getMinimumValue$a7d66b63a1df3c72(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *);
extern jint _jc_javax_swing_Spring__24SimpleSpring$method$getPreferredValue$c216b16eb60a1689(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *);
extern jint _jc_javax_swing_Spring__24SimpleSpring$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *);
extern void _jc_javax_swing_Spring__24SimpleSpring$method$setValue$e6840ec6b97bf5b1(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Spring__24SimpleSpring$method_info$getMaximumValue$dd51e3d6fecde040;
extern _jc_method _jc_javax_swing_Spring__24SimpleSpring$method_info$getMinimumValue$a7d66b63a1df3c72;
extern _jc_method _jc_javax_swing_Spring__24SimpleSpring$method_info$getPreferredValue$c216b16eb60a1689;
extern _jc_method _jc_javax_swing_Spring__24SimpleSpring$method_info$getValue$245714dca3f59de3;
extern _jc_method _jc_javax_swing_Spring__24SimpleSpring$method_info$setValue$e6840ec6b97bf5b1;

// Virtual methods structure
struct _jc_javax_swing_Spring__24SimpleSpring$vmethods {
	jint	(*getMaximumValue$dd51e3d6fecde040)(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *);
	jint	(*getMinimumValue$a7d66b63a1df3c72)(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *);
	jint	(*getPreferredValue$c216b16eb60a1689)(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *);
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *);
	void	(*setValue$e6840ec6b97bf5b1)(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *, jint);
};

// Vtable
struct _jc_javax_swing_Spring__24SimpleSpring$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Spring$vmethods	javax_swing_Spring;
	_jc_javax_swing_Spring__24SimpleSpring$vmethods	javax_swing_Spring__24SimpleSpring;
};

// Vtype
struct _jc_javax_swing_Spring__24SimpleSpring$vtype {
	_jc_type			type;
	_jc_javax_swing_Spring__24SimpleSpring$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Spring__24SimpleSpring$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_Spring__24SimpleSpring$refs {
    _jc_javax_swing_Spring__24SimpleSpring$sub_refs	javax_swing_Spring__24SimpleSpring;
    _jc_javax_swing_Spring$sub_refs	javax_swing_Spring;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Spring__24SimpleSpring$sub_nonrefs {
	jint	min;
	jint	pref;
	jint	max;
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Spring__24SimpleSpring$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Spring$sub_nonrefs	javax_swing_Spring;
    _jc_javax_swing_Spring__24SimpleSpring$sub_nonrefs	javax_swing_Spring__24SimpleSpring;
};

// Object instance structure
struct _jc_javax_swing_Spring__24SimpleSpring$object {
	_jc_javax_swing_Spring__24SimpleSpring$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Spring__24SimpleSpring$vtype	*vtype;
	_jc_javax_swing_Spring__24SimpleSpring$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Spring__24SimpleSpring$vtype _jc_javax_swing_Spring__24SimpleSpring$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Spring__24SimpleSpring, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Spring__24SimpleSpring$class_object;

#endif	/* _JC_javax_swing_Spring__24SimpleSpring_H_ */

==> jc-1.4.6.tar.gz: javax/swing/Spring__24SimpleSpring.h <==
// final class javax.swing.Spring$SimpleSpring

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 52c68a5c6f02978c javax_swing_Spring
// @dep_class 53749d8f1d14809a javax_swing_Spring__24SimpleSpring

// header file dependencies
// @dep_header javax_swing_Spring

#include "javax/swing/Spring.h"

#ifndef _JC_javax_swing_Spring__24SimpleSpring_H_
#define _JC_javax_swing_Spring__24SimpleSpring_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_Spring__24SimpleSpring$sub_refs	_jc_javax_swing_Spring__24SimpleSpring$sub_refs;
typedef struct _jc_javax_swing_Spring__24SimpleSpring$sub_nonrefs	_jc_javax_swing_Spring__24SimpleSpring$sub_nonrefs;
typedef struct _jc_javax_swing_Spring__24SimpleSpring$refs	_jc_javax_swing_Spring__24SimpleSpring$refs;
typedef struct _jc_javax_swing_Spring__24SimpleSpring$nonrefs	_jc_javax_swing_Spring__24SimpleSpring$nonrefs;
typedef struct _jc_javax_swing_Spring__24SimpleSpring$object	_jc_javax_swing_Spring__24SimpleSpring$object;

typedef const struct _jc_javax_swing_Spring__24SimpleSpring$vmethods	_jc_javax_swing_Spring__24SimpleSpring$vmethods;
typedef const struct _jc_javax_swing_Spring__24SimpleSpring$vtable	_jc_javax_swing_Spring__24SimpleSpring$vtable;
typedef const struct _jc_javax_swing_Spring__24SimpleSpring$vtype	_jc_javax_swing_Spring__24SimpleSpring$vtype;

// Constructors
extern void _jc_javax_swing_Spring__24SimpleSpring$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_Spring__24SimpleSpring$method$getMaximumValue$dd51e3d6fecde040(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_Spring__24SimpleSpring$method$getMinimumValue$a7d66b63a1df3c72(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_Spring__24SimpleSpring$method$getPreferredValue$c216b16eb60a1689(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_Spring__24SimpleSpring$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_Spring__24SimpleSpring$method$setValue$e6840ec6b97bf5b1(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Spring__24SimpleSpring$method_info$getMaximumValue$dd51e3d6fecde040;
extern _jc_method _jc_javax_swing_Spring__24SimpleSpring$method_info$getMinimumValue$a7d66b63a1df3c72;
extern _jc_method _jc_javax_swing_Spring__24SimpleSpring$method_info$getPreferredValue$c216b16eb60a1689;
extern _jc_method _jc_javax_swing_Spring__24SimpleSpring$method_info$getValue$245714dca3f59de3;
extern _jc_method _jc_javax_swing_Spring__24SimpleSpring$method_info$setValue$e6840ec6b97bf5b1;

// Virtual methods structure
struct _jc_javax_swing_Spring__24SimpleSpring$vmethods {
	jint	(*getMaximumValue$dd51e3d6fecde040)(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *) _JC_JCNI_ATTR;
	jint	(*getMinimumValue$a7d66b63a1df3c72)(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *) _JC_JCNI_ATTR;
	jint	(*getPreferredValue$c216b16eb60a1689)(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *) _JC_JCNI_ATTR;
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *) _JC_JCNI_ATTR;
	void	(*setValue$e6840ec6b97bf5b1)(_jc_env *, struct _jc_javax_swing_Spring__24SimpleSpring$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_Spring__24SimpleSpring$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Spring$vmethods	javax_swing_Spring;
	_jc_javax_swing_Spring__24SimpleSpring$vmethods	javax_swing_Spring__24SimpleSpring;
};

// Vtype
struct _jc_javax_swing_Spring__24SimpleSpring$vtype {
	_jc_type			type;
	_jc_javax_swing_Spring__24SimpleSpring$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Spring__24SimpleSpring$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_Spring__24SimpleSpring$refs {
    _jc_javax_swing_Spring__24SimpleSpring$sub_refs	javax_swing_Spring__24SimpleSpring;
    _jc_javax_swing_Spring$sub_refs	javax_swing_Spring;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Spring__24SimpleSpring$sub_nonrefs {
	jint	min;
	jint	pref;
	jint	max;
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Spring__24SimpleSpring$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Spring$sub_nonrefs	javax_swing_Spring;
    _jc_javax_swing_Spring__24SimpleSpring$sub_nonrefs	javax_swing_Spring__24SimpleSpring;
};

// Object instance structure
struct _jc_javax_swing_Spring__24SimpleSpring$object {
	_jc_javax_swing_Spring__24SimpleSpring$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Spring__24SimpleSpring$vtype	*vtype;
	_jc_javax_swing_Spring__24SimpleSpring$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Spring__24SimpleSpring$vtype _jc_javax_swing_Spring__24SimpleSpring$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Spring__24SimpleSpring, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Spring__24SimpleSpring$class_object;

#endif	/* _JC_javax_swing_Spring__24SimpleSpring_H_ */
